@@ -1,10 +1,15 @@
 reducir <-
 function(x,valores=NA,filas=TRUE,columnas=TRUE){
   a1=limpiar(x,valores,filas,columnas)
+  nomfilas=rownames(x)
+  nomcolumnas=colnames(x)
+  nomdim=names(dimnames(x))
   x2=x[a1$Filas,a1$Columnas]
-  dim(x2)=c(sum(a1$Filas),sum(a1$Columnas))
-  colnames(x2)=colnames(x)[a1$Columnas]
-  rownames(x2)=rownames(x)[a1$Filas]
+  #x2=t(t(x2))
+  if(!is.data.frame(x2)) dim(x2)=c(sum(a1$Filas),sum(a1$Columnas))
+  if(!is.null(nomfilas)) rownames(x2)=nomfilas[a1$Filas]
+  if(!is.null(nomcolumnas))colnames(x2)=nomcolumnas[a1$Columnas]
+  if(!is.null(nomdim)) names(dimnames(x2))=nomdim
   if(!inherits(x,"ftable") & 
      (is.null(attr(x,"cabFila")) | is.null(attr(x,"cabColumna")))){
     return(x2)
